.. _utilipy-printing:

*********************************************
IPython Printing (`utilipy.ipython.printing`)
*********************************************

.. currentmodule:: utilipy.ipython.printing


Reference/API
=============

.. automodapi:: utilipy.ipython.printing
